#include <oxstd.h>
#import <database>
#include "model.h"
#include "model.ox"
#include "taxes1.h"
#include "taxes1.ox"
#include "data.h"
#include "data.ox"
#include "estimate.h"
#include "estimate.ox"

loaduk(const model, const data, const n1, const n2, const n3)
{
	// creating starting values

	decl lambda = 0.096;
	decl delta = 0.0090;	
	decl mu1 = 7.07;
	decl mu2 = 7.76;
	decl pie = 0.84;
	decl sigma = 0.39;

	// reads wages from file
	
	decl database = new Database();	
	database.LoadObs("ukw95-jae.txt", 2, 24, 1, 1, 1, FALSE);
	decl ukw = database->GetVar("Var1")~database->GetVar("Var2");
	delete database;

	// reads durations from file
	
	database = new Database();
	database.LoadObs("durations-jae.txt", 6, 8, 1, 1, 1, FALSE);
	decl dur = database->GetVar("Var1")~database->GetVar("Var5");
	delete database;

	// reads unemployment benefits and household distribution from file
	
	database = new Database();
	database.LoadObs("benefits-jae.txt", 7, 3, 1, 1, 1, FALSE);
	decl oecd1 = database->GetVar("Var1");
	decl oecd2 = database->GetVar("Var2");
	decl probs = database->GetVar("Var5");
	delete database;

	database = new Database();
	database.LoadObs("unemployment-jae.txt", 2, 5, 1, 1, 1, FALSE);
	decl u = database->GetVar("Var2");
	delete database;
	
	decl minwag = 5475; // yearly minimum wage level
	u = u[3];

	dur = dur[:5][]|(24~dur[6][1:]+dur[7][1:]);
	decl m = probs;
	decl s = sumc(dur[0:5][1]) ./ sumc(dur[][1]);
	decl b1 = s.*oecd1+(1-s).*oecd2;

	// compute  reservation wages by using UK system
	
	decl b = berb(b1, fieuk, fieuk1, fieuk2, fieuk3); 
	decl hulp = sortbyc(b~m,0);
	b = hulp[][0];
	m = hulp[][1];

	decl wmin = minwag./12; // monthly minimum wage

	b = b.*(b.>0)+0 .*(b.<=0);

	// create model
	
	model[0] = new Model(lambda, delta, mu1, mu2, sigma, pie,  wmin, b, m);
				
	ukw[][0] = ukw[][0]./12;

	ukw = selectifr(ukw, ukw[][0] .> max(wmin|b[0]));

	decl c = ukw[][0];
	decl freq = ukw[][1];
	decl c1 = dur[][0];
	decl freq1 = dur[][1];

	n1[0] = sumc(freq).*1000;
	n2[0] = 5222;
	n3[0] = 54921+n2[0];
	
	freq = freq ./ sumc(freq);
	freq1 = freq1 ./ sumc(freq1);

	// create database
	
	data[0] = new Data(c1, c, freq1, freq, u);
	
	return 1;
}

showresults(const result)
{
	println("\n\nLambda:\t", result[0]);
	println("Delta:\t", result[1]);
	println("Mu1:\t", result[2]);
	println("Mu2:\t", result[3]);
	println("Sigma:\t", result[4]);
	println("Pie:\t", result[5]);
}

main()
{
	decl model, data, n1, n2, n3, result;
	loaduk(&model, &data, &n1, &n2, &n3);
	
	decl estimate =	new Estimate(model, data, n1, n2, n3);
	estimate.DoEstimate(&result);

	showresults(result);
	
	return 1;
}